package KittenFarm::C::Test;

use strict;
use base 'Catalyst::Base';

=head1 NAME

KittenFarm::C::Test - Scaffolding Controller Component

=head1 SYNOPSIS

See L<KittenFarm>

=head1 DESCRIPTION

Scaffolding Controller Component.

=head1 METHODS

=over 4

=item add

Sets a template.

=cut

sub add : Local {
    my ( $self, $c ) = @_;
    $c->stash->{template} = 'Test/add.tt';
}

=item default

Forwards to list.

=cut

sub default : Private {
    my ( $self, $c ) = @_;
    $c->forward('list');
}

=item destroy

Destroys a row and forwards to list.

=cut

sub destroy : Local {
    my ( $self, $c, $id ) = @_;
    KittenFarm::M::Database::Test->find($id)->delete;
    $c->forward('list');
}

=item do_add

Adds a new row to the table and forwards to list.

=cut

sub do_add : Local {
    my ( $self, $c ) = @_;
    $c->form( optional => [ KittenFarm::M::Database::Test->columns ] );
    KittenFarm::M::Database::Test->create_from_form( $c->form );
    $c->forward('list');
}

=item do_edit

Edits a row and forwards to edit.

=cut

sub do_edit : Local {
    my ( $self, $c, $id ) = @_;
    $c->form( optional => [ $self->table_class($c)->columns ] );
    $self->table_class($c)->find($id)->update_from_form( $c->form );
    $c->forward('edit');
}

=item edit

Sets a template.

=cut

sub edit : Local {
    my ( $self, $c, $id ) = @_;
    $c->stash->{item} = $self->table_class($c)->find($id);
    $c->stash->{template} = 'Test/edit.tt';
}

=item list

Sets a template.

=cut

sub list : Local {
    my ( $self, $c ) = @_;
    $c->stash->{rs} = $self->table_class($c)->search({});
    $c->stash->{template} = 'Test/list.tt';
}

=item view

Fetches a row and sets a template.

=cut

sub view : Local {
    my ( $self, $c, $id ) = @_;
    $c->stash->{item} = $self->table_class($c)->find($id);
    $c->stash->{template} = 'Test/view.tt';
}

sub end : Private {
    my ( $self, $c ) = @_;
    $c->forward('KittenFarm::V::TT');
}

sub table_class {
  my ( $self, $c ) = @_;
  return $c->comp('KittenFarm::M::Database')->class('Test'); 
}

=back

=head1 AUTHOR

Matt S Trout

=head1 LICENSE

This library is free software . You can redistribute it and/or modify
it under the same terms as perl itself.

=cut

1;
